@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -76,7 +76,7 @@ static const QString SMeaning = "<b>Superior</b>  <i>(head of the patient)</i>
 // --------------- constructor -------------------
 ReorientImage::ReorientImage(ActionExtension* extension) : Action(extension) {
     setName("Reorient Medical Image");
-    setDescription(tr("This action allows to re-orient a medical image according to Dicom RCS (Reference Coordinates System) system."));
+    setDescription(tr("This action re-orients a medical image according to Dicom RCS (Reference Coordinates System)."));
     setComponent("ImageComponent");
 
     // Setting classification family and tags
@@ -135,7 +135,7 @@ ReorientImage::~ReorientImage() {
 }
 
 // --------------- initDialog -------------------
-void ReorientImage::initDialog() {        
+void ReorientImage::initDialog() {
     dialog = new QDialog();
 
     //-- init user interface
@@ -195,7 +195,7 @@ void ReorientImage::initInternalViewer() {
     buildTransforms();
     // get the nice vtk 3D representation from file
     buildGeometries();
-    
+
     // Set up the 3D viewer to visualize actual origin/orientation locations
     internalViewer = InteractiveViewer::getNewViewer("Image Orientation Viewer", InteractiveViewer::GEOMETRY_VIEWER);
     internalViewer->setHighlightMode(InteractiveViewer::OFF);
@@ -224,9 +224,9 @@ void ReorientImage::rcsChanged(const QString index) {
 
 // --------------- modelChanged -------------------
 void ReorientImage::modelChanged(bool displayMaleModel) {
-    if (femaleModel==NULL || maleModel==NULL) 
+    if (femaleModel==NULL || maleModel==NULL)
         return;
-    
+
     if (displayMaleModel) {
         internalViewer->getRendererWidget()->removeProp(femaleModel->getActor(InterfaceGeometry::Surface));
         internalViewer->getRendererWidget()->addProp(maleModel->getActor(InterfaceGeometry::Surface));
@@ -250,6 +250,12 @@ QWidget * ReorientImage::getWidget() {
 
 //--------------- apply ------------
 Action::ApplyStatus ReorientImage::apply() {
+
+    if(!dialog) {
+        CAMITK_ERROR("ReorientImage", "process", "Calling apply() without having initializing its QWidget => this is prohibited at the moment, aborting ...");
+        return ABORTED;
+    }
+
     ImageComponent * img = dynamic_cast<ImageComponent *> (getTargets().last());
 
     return process(img);
@@ -272,6 +278,7 @@ Action::ApplyStatus ReorientImage::process( ImageComponent * image) {
     ui.zDirection->setText(lettersMeaning.value(zLetter));
 
     ImageOrientationHelper::PossibleImageOrientations orient = (ImageOrientationHelper::PossibleImageOrientations) (index);
+
     // 2- Compute the reslice matrix according to the new orientation
     double * imgSpacing = image->getImageData()->GetSpacing();
     int * imgDims    = image->getImageData()->GetDimensions();
@@ -287,12 +294,11 @@ Action::ApplyStatus ReorientImage::process( ImageComponent * image) {
     // 3- Create a new ImageComponent with the resliced image.
 
     vtkSmartPointer<vtkImageReslice> imageResliceFilter = vtkSmartPointer<vtkImageReslice>::New();
-    imageResliceFilter->SetInput(image->getImageData());
+    imageResliceFilter->SetInputData(image->getImageData());
     imageResliceFilter->SetOutputDimensionality(3);
     imageResliceFilter->SetResliceAxes(transform->GetMatrix());
 
     vtkSmartPointer<vtkImageData> newData = imageResliceFilter->GetOutput();
-    newData->Update();
 
     if (ui.noNewImageCheckBox->isChecked()) {
         image->replaceImageData(newData);
@@ -465,8 +471,7 @@ void ReorientImage::buildGeometries() {
         QString femaleModelFilename = globalTestDir.canonicalPath() + "/female.vtk";
         femaleModel = VtkMeshUtil::vtkToGeometry(femaleModelFilename.toStdString());
         femaleModel->setColor(1.0, 0.75, 0.64);
-    }
-    else {
+    } else {
         CAMITK_WARNING("ReorientImage", "buildGeometries", "3D Model VTK files not found");
     }
 }
