@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,12 +31,12 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
+
 ComponentsCreationWidget::ComponentsCreationWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
 
-/**  Destructor */
+
 ComponentsCreationWidget::~ComponentsCreationWidget() {}
 
 void ComponentsCreationWidget::setToDefault() {
@@ -47,6 +47,7 @@ void ComponentsCreationWidget::setToDefault() {
 
 void ComponentsCreationWidget::nextButtonClicked() {
     // check if at least an action has been created
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (createdComponents.isEmpty()) {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.label_Star->setStyleSheet(enhancedStyle);
@@ -58,6 +59,9 @@ void ComponentsCreationWidget::nextButtonClicked() {
 
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ComponentsCreationWidget::addComponentClicked() {
