@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -53,52 +53,11 @@ inline void initMyResource() {
 
 using namespace cepcoreschema;
 
-bool CepGenerator::generateCEP(QString xmlFileName, QString devDirectoryName) {
-
-    try {
-        std::cout << "Generating CEP..." << std::endl;
-        CepGenerator * generator = new CepGenerator(xmlFileName, devDirectoryName);
-        generator->createDomTree();
-        generator->generateDirectoryTree();
-        generator->createComponentExtensionDoms();
-        generator->createActionExtensionDoms();
-        generator->createLibrarieDoms();
-        generator->generateExtensions();
-        delete generator;
-    } catch (QString msg) {
-        std::cout << msg.toStdString() << std::endl;
-        std::cout << "Could not generate CEP, sorry..." << std::endl;
-        return false;
-    }
-
-    return true;
-}
-
-bool CepGenerator::generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName) {
-
-    try {
-        std::cout << "Generating CEP..." << std::endl;
-        CepGenerator * generator = new CepGenerator(domCep, devDirectoryName);
-//        generator->createDomTree();
-        generator->generateDirectoryTree();
-        generator->createComponentExtensionDoms();
-        generator->createActionExtensionDoms();
-        generator->createLibrarieDoms();
-        generator->generateExtensions();
-        delete generator;
-    } catch (QString msg) {
-        std::cout << msg.toStdString() << std::endl;
-        std::cout << "Could not generate CEP, sorry..." << std::endl;
-        return false;
-    }
-
-    return true;
-}
-
 CepGenerator::CepGenerator(QString xmlFilename, QString devDirectoryName) {
     initMyResource();
     setXmlFileName(xmlFilename);
     setDevDirectoryName(devDirectoryName);
+    createDomTree();
 }
 
 CepGenerator::CepGenerator(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName) {
@@ -143,8 +102,7 @@ void CepGenerator::createDomTree() throw (QString) {
 
     try {
         this->domCep = cep(xmlFileStr, xml_schema::flags::dont_validate);
-        setLicence();
-    } catch (const xml_schema::exception& e) {        
+    } catch (const xml_schema::exception& e) {
         std::cout << "Error Parsing XML file:" << std::endl;
         std::cout << e << std::endl;
         throw QString(e.what());
@@ -483,3 +441,12 @@ void CepGenerator::generateExtensions() {
     }
 
 }
+
+void CepGenerator::process() throw (QString) {
+    setLicence();
+    generateDirectoryTree();
+    createComponentExtensionDoms();
+    createActionExtensionDoms();
+    createLibrarieDoms();
+    generateExtensions();
+}
